==> encryptly-client-1.0.3.tgz: package/README.md <==
# encryptly-client
### Encryptly client library (to be used in frontend)

_Installing and updating the client (client side)_
```
npm i encryptly-client@latest

or 

yarn add encryptly-client@latest
```

_Instructions_

There are two ways your users will be redirected to
authentication server:
1. Popup
2. Page redirect

_METHOD 1: Popup_

Your client should open a window using javascript.
```javascript
// STEP 1: Create popup (client side)
import { createPopup } from "encryptly-client";

const serverUrl = "https://auth.encryptly.net";
const clientId = "<YOUR GENERATED CLIENT ID>";
const type = "login"; // or "register"
createPopup({serverUrl, clientId, type}, token => handleEncryptlyResponse(token))

// You will need to create "handleEncryptlyResponse" function
// or whatever you want to call it
// Next step involves verifying the token from "createPopup" response

// STEP 2: Verify token (server side)
// Example: NodeJS express auth controller
```

_METHOD 2: Page Redirect_

After a successful login, users will be redirected to the
specified redirect URL. This can be useful when the user
is visiting your app on mobile

```javascript
// STEP 1: Redirect user to authentication server (client side)
import { redirectToAuthServer } from "encryptly-client";

const serverUrl = "https://auth.encryptly.net";
const clientId = "<YOUR GENERATED CLIENT ID>";
const type = "login"; // or "register"
const redirectUrl = "<YOUR APP'S SERVER REDIRECT URL>"
redirectToAuthServer({serverUrl, clientId, type, redirectUrl})

// The only difference from the popup method
// is that here you specify "redirectUrl"

// STEP 2: Verify token after successful login (server side)
// This can be done using the same controller method as
// in STEP 2 for popup method, except that you
// will need to redirect to your frontend
```

==> encryptly-client-1.0.8.tgz: package/README.md <==
# encryptly-client
### Encryptly client library (to be used in frontend)

_Installing and updating the client (client side)_
```
npm i encryptly-client@latest

or 

yarn add encryptly-client@latest
```

_Instructions_

There are two ways your users will be redirected to
authentication server:
1. Popup
2. Page redirect

_METHOD 1: Popup_

Your client should open a window using javascript.
```javascript
// STEP 1: Create popup (client side)
import { createPopup } from "encryptly-client";

const serverUrl = "https://auth.encryptly.net";
const clientId = "<YOUR GENERATED CLIENT ID>";
const type = "login"; // or "register"
createPopup({serverUrl, clientId, type}, token => handleEncryptlyResponse(token))

// You will need to create "handleEncryptlyResponse" function
// or whatever you want to call it
// Next step involves verifying the token from "createPopup" response

// STEP 2: Verify token (server side)
// Example: NodeJS express auth controller
```

_METHOD 2: Page Redirect_

After a successful login, users will be redirected to the
specified redirect URL. This can be useful when the user
is visiting your app on mobile

```javascript
// STEP 1: Redirect user to authentication server (client side)
import { redirectToAuthServer } from "encryptly-client";

const serverUrl = "https://auth.encryptly.net";
const clientId = "<YOUR GENERATED CLIENT ID>";
const type = "login"; // or "register"
// NOTE: the following "redirectUrl" is NOT the
// --redirect-url option from the CLI.
// It is most likely the current page that your
// user is visiting, or any other page on the client
// that you want your users to be redirected to
// after successful login
const redirectUrl = "<URL THAT YOUR USERS WILL BE REDIRECTED TO>"
redirectToAuthServer({serverUrl, clientId, type, redirectUrl})

// The only difference from the popup method
// is that here you specify "redirectUrl"

// STEP 2: Verify token after successful login (server side)
// This can be done using the same controller method as
// in STEP 2 for popup method, except that you
// will need to redirect to your frontend
```
